#!/usr/bin/env python
# vim: set ts=4 sts=4 sw=4 textwidth=92:

import PAR2Set.Base
import rsutil.common

#
# This is an new-style rar type
#
# It will detect sets like the following:
# X.par2
# X.vol0+1.par2
# X.vol1+2.par2
# X.part01.rar
# X.part02.rar
# X.part03.rar
#
# OR
#
# ABC.part01.rar
# ABC.part02.rar
# ABC.part03.rar
#
# Where the PAR2 files protect all files that do not match in basename
# with the PAR2 file itself.
#

def detector (name_files, prot_files):
	return rsutil.common.has_a_match ('^.*\.part0*1\.rar$', prot_files)


class NewRAR (PAR2Set.Base.Base):

	def __repr__ (self):
		return 'NEWRAR'

	def find_extraction_heads (self):
		return rsutil.common.find_matches ('^.*\.part0*1\.rar$', self.all_files)

	def extraction_function (self, file, todir):
		assert os.path.isfile (file)
		assert os.path.isdir (todir)

		RAR_CMD = rsutil.common.config_get_value ('commands', 'unrar')

		cmd = '%s \"%s\"' % (RAR_CMD, file)
		ret = rsutil.common.run_command (cmd, todir)

		# Check error code
		if ret != 0:
			return -rsutil.common.EEXTRACT

		return rsutil.common.SUCCESS

